bayespy.inference.vmp.transformations.RotateMultiple.setup
==========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateMultiple.setup